#### CandlePart options

```python
from stock_indicators.indicators.common.enums import CandlePart
```

| type | description
|-- |--
| `CandlePart.OPEN` | `open` price
| `CandlePart.HIGH` | `high` price
| `CandlePart.LOW` | `low` price
| `CandlePart.CLOSE` | `close` price
| `CandlePart.VOLUME` | `volume`
| `CandlePart.HL2` | `(high+low)/2`
| `CandlePart.HLC3` | `(high+low+close)/3`
| `CandlePart.OC2` | `(open+close)/2`
| `CandlePart.OHL3` | `(open+high+low)/3`
| `CandlePart.OHLC4` | `(open+high+low+close)/4`
